=======
History
=======

0.1.1 (2019-12-30)
------------------

* various minor fixes to get pypi deployment working.


0.1.0 (2019-12-30)
------------------

* ``UniqueTuple``
* benchmarking via pytest-benchmark
* ``AttyDict``
* ``ops``module w/ recursive gettattr and setattr functions.